@@ -6,7 +6,7 @@ from .factors_handler.factors_handlers import store_optimized_radius, get_optimi
 
 from .misc.timer import my_timer
 from .misc.path_searcher import path_finder
-
+from .misc.create_gif import create_gif
 from .misc.parameters_validator import parameters_validator
 
 from .noise_metrics.CDPP import CDPP
@@ -15,5 +15,7 @@ from .noise_metrics.DRP_CDPP import DRP_CDPP
 from .data_export.export_fits import create_fits
 from .data_export.export_txt import export_txt
 from .data_export.export_photo_info import photo_SaveInfo
+from .data_export.folder_handler import handle_folders
+
 
 from .image_processing import  shape_analysis, calculate_moments, shape_increase
\ No newline at end of file
